( cd usr/bin ; rm -rf rec )
( cd usr/bin ; ln -sf play rec )
( cd usr/man/man1 ; rm -rf soxmix.1.gz )
( cd usr/man/man1 ; ln -sf sox.1.gz soxmix.1.gz )
( cd usr/man/man1 ; rm -rf rec.1.gz )
( cd usr/man/man1 ; ln -sf play.1.gz rec.1.gz )
